@@ -1,7 +1,7 @@
 from pydantic import BaseModel
 from typing import Optional, List
 from enum import IntEnum
-from agricore_sp_models.common_models import OrganicProductionType, ProductGroupJsonDTO, LandRentJsonDTO, LandRentDTO, PolicyJsonDTO
+from agricore_sp_models.common_models import OrganicProductionType, ProductGroupJsonDTO, LandRentJsonDTO, LandRentDTO, PolicyJsonDTO, PolicyGroupRelationJsonDTO
 from pydantic import confloat
     
 class AgriculturalProduction(BaseModel):
@@ -135,6 +135,14 @@ class FADNProductRelation(BaseModel):
     productGroupId: Optional[int] = None
     fadnProductId: Optional[int] = None
     populationId: Optional[int] = None
+    # The representativeness of the FADN product in the product group. Item representativeness should be calculated
+    # as the representativeness of the FADN product divided by the sum of the representativeness of all FADN products in the product group.
+    # For its calculation, remember than whe obtaining data from the sample, the weight of such farm in the population should be taken into account
+    representativenessOcurrence: Optional[float] = None
+    # In hectars
+    representativenessArea: Optional[float] = None
+    # In €
+    representativenessValue: Optional[float] = None
 
 class ClosingValue(BaseModel):
     id: Optional[int] = None
@@ -209,6 +217,7 @@ class PolicyProductGroupRelation(BaseModel):
     productGroupId: int
     policyId: int
     populationId: Optional[int] = None
+    economicCompensation:float
 
 class HolderFarmYearData(BaseModel):
     id: Optional[int] = None
@@ -228,6 +237,7 @@ class FarmYearSubsidy(BaseModel):
     value: float
 
 class FarmYearSubsidyDTO(BaseModel):
+    farmId: Optional[int] = None
     yearNumber: int
     value: float
     policyIdentifier: str
@@ -338,10 +348,8 @@ class ValueToSPDTO(BaseModel):
 class DataToSPDTO(BaseModel):
     values: List[ValueToSPDTO]
     productGroups: List[ProductGroupJsonDTO]
-    # Deprecated
-    coupledSubsidiesProductGroupsDict: dict[str,List[str]]
     policies: List[PolicyJsonDTO]
-    productGroups: List[ProductGroupJsonDTO]
+    policyGroupRelations: List[PolicyGroupRelationJsonDTO]
     farmYearSubsidies: List[FarmYearSubsidyDTO]
 
 class IntermediateValueFromLP(BaseModel):
