@@ -1,4 +1,4 @@
-from agricore_sp_models.common_models import OrganicProductionType, PolicyJsonDTO, ProductGroupJsonDTO
+from agricore_sp_models.common_models import OrganicProductionType, PolicyJsonDTO, ProductGroupJsonDTO, LandRentJsonDTO, PolicyGroupRelationJsonDTO
 from pydantic import BaseModel, Field
 from typing import List
 
@@ -145,15 +145,6 @@ class LandTransactionJsonDTO(BaseModel):
     # Sale price of the land transferred from the origin farm to the destination farm [€]
     salePrice: float
     
-class LandRentJsonDTO(BaseModel):
-    yearNumber: int
-    originFarmCode: str
-    destinationFarmCode: str
-    # Total Rent Price [€]
-    rentValue: float
-    # Total Rent Area [ha]
-    rentArea: float
-    
 class GreeningFarmYearDataJsonDTO(BaseModel):
     yearNumber: int
     # Greening Surface [ha]
@@ -182,9 +173,10 @@ class PopulationJsonDTO(BaseModel):
     description: str = ""
     farms: List[FarmJsonDTO]
     productGroups: List[ProductGroupJsonDTO]
-    uncoupledPolicies: List[PolicyJsonDTO]
+    policies: List[PolicyJsonDTO]
     landTransactions: List[LandTransactionJsonDTO]
     landRents: List[LandRentJsonDTO]
+    policyGroupRelations: List[PolicyGroupRelationJsonDTO]
 
 class SyntheticPopulationJsonDTO(BaseModel):
     description: str = ""
